aboutsummaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/serd_test.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/serd_test.c b/tests/serd_test.c
index b80c8b82..62621e16 100644
--- a/tests/serd_test.c
+++ b/tests/serd_test.c
@@ -573,10 +573,10 @@ main(void)
serd_writer_free(writer);
- // Test chunk sink
- SerdChunk chunk = { NULL, 0 };
+ // Test buffer sink
+ SerdBuffer buffer = { NULL, 0 };
writer = serd_writer_new(
- SERD_TURTLE, (SerdStyle)0, env, NULL, serd_chunk_sink, &chunk);
+ SERD_TURTLE, (SerdStyle)0, env, NULL, serd_buffer_sink, &buffer);
o = serd_node_from_string(SERD_URI, USTR("http://example.org/base"));
if (serd_writer_set_base_uri(writer, &o)) {
@@ -584,10 +584,10 @@ main(void)
}
serd_writer_free(writer);
- uint8_t* out = serd_chunk_sink_finish(&chunk);
+ uint8_t* out = serd_buffer_sink_finish(&buffer);
if (strcmp((const char*)out, "@base <http://example.org/base> .\n")) {
- FAILF("Incorrect chunk output:\n%s\n", chunk.buf);
+ FAILF("Incorrect buffer output:\n%s\n", buffer.buf);
}
free(out);